@@ -4,7 +4,7 @@ import (
 	"context"
 	"errors"
 	"fmt"
-	"log" //nolint:revive
+	"log"
 	"os"
 	"os/signal"
 	"strings"
@@ -26,6 +26,7 @@ import (
 	"github.com/influxdata/telegraf/plugins/outputs"
 	"github.com/influxdata/telegraf/plugins/parsers"
 	"github.com/influxdata/telegraf/plugins/processors"
+	"github.com/influxdata/telegraf/plugins/secretstores"
 )
 
 var stop chan struct{}
@@ -55,13 +56,19 @@ type WindowFlags struct {
 type App interface {
 	Init(<-chan error, Filters, GlobalFlags, WindowFlags)
 	Run() error
+
+	// Secret store commands
+	ListSecretStores() ([]string, error)
+	GetSecretStore(string) (telegraf.SecretStore, error)
 }
 
 type Telegraf struct {
 	pprofErr <-chan error
 
-	inputFilters  []string
-	outputFilters []string
+	inputFilters       []string
+	outputFilters      []string
+	configFiles        []string
+	secretstoreFilters []string
 
 	GlobalFlags
 	WindowFlags
@@ -71,11 +78,45 @@ func (t *Telegraf) Init(pprofErr <-chan error, f Filters, g GlobalFlags, w Windo
 	t.pprofErr = pprofErr
 	t.inputFilters = f.input
 	t.outputFilters = f.output
+	t.secretstoreFilters = f.secretstore
 	t.GlobalFlags = g
 	t.WindowFlags = w
 }
 
+func (t *Telegraf) ListSecretStores() ([]string, error) {
+	c, err := t.loadConfiguration()
+	if err != nil {
+		return nil, err
+	}
+
+	ids := make([]string, 0, len(c.SecretStores))
+	for k := range c.SecretStores {
+		ids = append(ids, k)
+	}
+	return ids, nil
+}
+
+func (t *Telegraf) GetSecretStore(id string) (telegraf.SecretStore, error) {
+	c, err := t.loadConfiguration()
+	if err != nil {
+		return nil, err
+	}
+
+	store, found := c.SecretStores[id]
+	if !found {
+		return nil, errors.New("unknown secret store")
+	}
+
+	return store, nil
+}
+
 func (t *Telegraf) reloadLoop() error {
+	reloadConfig := false
+	cfg, err := t.loadConfiguration()
+	if err != nil {
+		return err
+	}
+
 	reload := make(chan bool, 1)
 	reload <- true
 	for <-reload {
@@ -86,7 +127,7 @@ func (t *Telegraf) reloadLoop() error {
 		signal.Notify(signals, os.Interrupt, syscall.SIGHUP,
 			syscall.SIGTERM, syscall.SIGINT)
 		if t.watchConfig != "" {
-			for _, fConfig := range t.config {
+			for _, fConfig := range t.configFiles {
 				if _, err := os.Stat(fConfig); err == nil {
 					go t.watchLocalConfig(signals, fConfig)
 				} else {
@@ -111,10 +152,11 @@ func (t *Telegraf) reloadLoop() error {
 			}
 		}()
 
-		err := t.runAgent(ctx)
-		if err != nil && err != context.Canceled {
-			return fmt.Errorf("[telegraf] Error running agent: %v", err)
+		err := t.runAgent(ctx, cfg, reloadConfig)
+		if err != nil && !errors.Is(err, context.Canceled) {
+			return fmt.Errorf("[telegraf] Error running agent: %w", err)
 		}
+		reloadConfig = true
 	}
 
 	return nil
@@ -160,29 +202,40 @@ func (t *Telegraf) watchLocalConfig(signals chan os.Signal, fConfig string) {
 	signals <- syscall.SIGHUP
 }
 
-func (t *Telegraf) runAgent(ctx context.Context) error {
+func (t *Telegraf) loadConfiguration() (*config.Config, error) {
 	// If no other options are specified, load the config file and run.
 	c := config.NewConfig()
 	c.OutputFilters = t.outputFilters
 	c.InputFilters = t.inputFilters
-	var err error
+	c.SecretStoreFilters = t.secretstoreFilters
+
+	var configFiles []string
 	// providing no "config" flag should load default config
 	if len(t.config) == 0 {
-		err = c.LoadConfig("")
-		if err != nil {
-			return err
-		}
-	}
-	for _, fConfig := range t.config {
-		err = c.LoadConfig(fConfig)
-		if err != nil {
-			return err
-		}
+		configFiles = append(configFiles, "")
+	} else {
+		configFiles = append(configFiles, t.config...)
 	}
 
 	for _, fConfigDirectory := range t.configDir {
-		err = c.LoadDirectory(fConfigDirectory)
+		files, err := config.WalkDirectory(fConfigDirectory)
 		if err != nil {
+			return c, err
+		}
+		configFiles = append(configFiles, files...)
+	}
+
+	t.configFiles = configFiles
+	if err := c.LoadAll(configFiles...); err != nil {
+		return c, err
+	}
+	return c, nil
+}
+
+func (t *Telegraf) runAgent(ctx context.Context, c *config.Config, reloadConfig bool) error {
+	var err error
+	if reloadConfig {
+		if c, err = t.loadConfiguration(); err != nil {
 			return err
 		}
 	}
@@ -215,22 +268,23 @@ func (t *Telegraf) runAgent(ctx context.Context) error {
 		LogWithTimezone:     c.Agent.LogWithTimezone,
 	}
 
-	err = logger.SetupLogging(logConfig)
-	if err != nil {
+	if err := logger.SetupLogging(logConfig); err != nil {
 		return err
 	}
 
 	log.Printf("I! Starting Telegraf %s%s", internal.Version, internal.Customized)
-	log.Printf("I! Available plugins: %d inputs, %d aggregators, %d processors, %d parsers, %d outputs",
+	log.Printf("I! Available plugins: %d inputs, %d aggregators, %d processors, %d parsers, %d outputs, %d secret-stores",
 		len(inputs.Inputs),
 		len(aggregators.Aggregators),
 		len(processors.Processors),
 		len(parsers.Parsers),
 		len(outputs.Outputs),
+		len(secretstores.SecretStores),
 	)
 	log.Printf("I! Loaded inputs: %s", strings.Join(c.InputNames(), " "))
 	log.Printf("I! Loaded aggregators: %s", strings.Join(c.AggregatorNames(), " "))
 	log.Printf("I! Loaded processors: %s", strings.Join(c.ProcessorNames(), " "))
+	log.Printf("I! Loaded secretstores: %s", strings.Join(c.SecretstoreNames(), " "))
 	if !t.once && (t.test || t.testWait != 0) {
 		log.Print("W! " + color.RedString("Outputs are not used in testing mode!"))
 	} else {
@@ -250,12 +304,12 @@ func (t *Telegraf) runAgent(ctx context.Context) error {
 	if count, found := c.Deprecations["outputs"]; found && (count[0] > 0 || count[1] > 0) {
 		log.Printf("W! Deprecated outputs: %d and %d options", count[0], count[1])
 	}
-
-	ag, err := agent.NewAgent(c)
-	if err != nil {
-		return err
+	if count, found := c.Deprecations["secretstores"]; found && (count[0] > 0 || count[1] > 0) {
+		log.Printf("W! Deprecated secretstores: %d and %d options", count[0], count[1])
 	}
 
+	ag := agent.NewAgent(c)
+
 	// Notify systemd that telegraf is ready
 	// SdNotify() only tries to notify if the NOTIFY_SOCKET environment is set, so it's safe to call when systemd isn't present.
 	// Ignore the return values here because they're not valid for platforms that don't use systemd.
