@@ -6,6 +6,7 @@ import (
 	_ "embed"
 	"encoding/binary"
 	"encoding/json"
+	"errors"
 	"fmt"
 	"io"
 	"net"
@@ -177,8 +178,7 @@ func (c *CiscoTelemetryMDT) Start(acc telegraf.Accumulator) error {
 		var opts []grpc.ServerOption
 		tlsConfig, err := c.ServerConfig.TLSConfig()
 		if err != nil {
-			//nolint:errcheck,revive // we cannot do anything if the closing fails
-			c.listener.Close()
+			c.listener.Close() //nolint:revive // we cannot do anything if the closing fails
 			return err
 		} else if tlsConfig != nil {
 			opts = append(opts, grpc.Creds(credentials.NewTLS(tlsConfig)))
@@ -188,7 +188,8 @@ func (c *CiscoTelemetryMDT) Start(acc telegraf.Accumulator) error {
 			opts = append(opts, grpc.MaxRecvMsgSize(c.MaxMsgSize))
 		}
 
-		if c.EnforcementPolicy.PermitKeepaliveWithoutCalls || (c.EnforcementPolicy.KeepaliveMinTime != 0 && c.EnforcementPolicy.KeepaliveMinTime != defaultKeepaliveMinTime) {
+		if c.EnforcementPolicy.PermitKeepaliveWithoutCalls ||
+			(c.EnforcementPolicy.KeepaliveMinTime != 0 && c.EnforcementPolicy.KeepaliveMinTime != defaultKeepaliveMinTime) {
 			// Only set if either parameter does not match defaults
 			opts = append(opts, grpc.KeepaliveEnforcementPolicy(keepalive.EnforcementPolicy{
 				MinTime:             time.Duration(c.EnforcementPolicy.KeepaliveMinTime),
@@ -208,8 +209,7 @@ func (c *CiscoTelemetryMDT) Start(acc telegraf.Accumulator) error {
 		}()
 
 	default:
-		//nolint:errcheck,revive // we cannot do anything if the closing fails
-		c.listener.Close()
+		c.listener.Close() //nolint:revive // we cannot do anything if the closing fails
 		return fmt.Errorf("invalid Cisco MDT transport: %s", c.Transport)
 	}
 
@@ -224,7 +224,8 @@ func (c *CiscoTelemetryMDT) acceptTCPClients() {
 
 	for {
 		conn, err := c.listener.Accept()
-		if neterr, ok := err.(*net.OpError); ok && (neterr.Timeout() || neterr.Temporary()) {
+		var neterr *net.OpError
+		if errors.As(err, &neterr) && (neterr.Timeout() || neterr.Temporary()) {
 			continue
 		} else if err != nil {
 			break // Stop() will close the connection so Accept() will fail here
@@ -319,8 +320,8 @@ func (c *CiscoTelemetryMDT) MdtDialout(stream dialout.GRPCMdtDialout_MdtDialoutS
 	for {
 		packet, err := stream.Recv()
 		if err != nil {
-			if err != io.EOF {
-				c.acc.AddError(fmt.Errorf("GRPC dialout receive error: %v", err))
+			if !errors.Is(err, io.EOF) {
+				c.acc.AddError(fmt.Errorf("GRPC dialout receive error: %w", err))
 			}
 			break
 		}
@@ -335,7 +336,7 @@ func (c *CiscoTelemetryMDT) MdtDialout(stream dialout.GRPCMdtDialout_MdtDialoutS
 			c.handleTelemetry(packet.Data)
 		} else if int(packet.TotalSize) <= c.MaxMsgSize {
 			if _, err := chunkBuffer.Write(packet.Data); err != nil {
-				c.acc.AddError(fmt.Errorf("writing packet %q failed: %v", packet.Data, err))
+				c.acc.AddError(fmt.Errorf("writing packet %q failed: %w", packet.Data, err))
 			}
 			if chunkBuffer.Len() >= int(packet.TotalSize) {
 				c.handleTelemetry(chunkBuffer.Bytes())
@@ -358,7 +359,7 @@ func (c *CiscoTelemetryMDT) handleTelemetry(data []byte) {
 	msg := &telemetry.Telemetry{}
 	err := proto.Unmarshal(data, msg)
 	if err != nil {
-		c.acc.AddError(fmt.Errorf("failed to decode: %v", err))
+		c.acc.AddError(fmt.Errorf("failed to decode: %w", err))
 		return
 	}
 
@@ -405,7 +406,18 @@ func (c *CiscoTelemetryMDT) handleTelemetry(data []byte) {
 
 		// Parse values
 		for _, subfield := range content.Fields {
-			c.parseContentField(grouper, subfield, "", msg.EncodingPath, tags, timestamp)
+			prefix := ""
+			switch subfield.Name {
+			case "operation-metric":
+				if len(subfield.Fields[0].Fields) > 0 {
+					prefix = subfield.Fields[0].Fields[0].GetStringValue()
+				}
+			case "class-stats":
+				if len(subfield.Fields[0].Fields) > 1 {
+					prefix = subfield.Fields[0].Fields[1].GetStringValue()
+				}
+			}
+			c.parseContentField(grouper, subfield, prefix, msg.EncodingPath, tags, timestamp)
 		}
 	}
 
@@ -502,9 +514,7 @@ func (c *CiscoTelemetryMDT) parseRib(grouper *metric.SeriesGrouper, field *telem
 			tags[subfield.Name] = decodeTag(subfield)
 		}
 		if value := decodeValue(subfield); value != nil {
-			if err := grouper.Add(measurement, tags, timestamp, subfield.Name, value); err != nil {
-				c.Log.Errorf("adding field %q to group failed: %v", subfield.Name, err)
-			}
+			grouper.Add(measurement, tags, timestamp, subfield.Name, value)
 		}
 		if subfield.Name != "nextHop" {
 			continue
@@ -519,9 +529,7 @@ func (c *CiscoTelemetryMDT) parseRib(grouper *metric.SeriesGrouper, field *telem
 				}
 				if value := decodeValue(ff); value != nil {
 					name := "nextHop/" + ff.Name
-					if err := grouper.Add(measurement, tags, timestamp, name, value); err != nil {
-						c.Log.Errorf("adding field %q to group failed: %v", name, err)
-					}
+					grouper.Add(measurement, tags, timestamp, name, value)
 				}
 			}
 		}
@@ -586,13 +594,9 @@ func (c *CiscoTelemetryMDT) parseContentField(grouper *metric.SeriesGrouper, fie
 		}
 
 		if val := c.nxosValueXform(field, value, encodingPath); val != nil {
-			if err := grouper.Add(measurement, tags, timestamp, name, val); err != nil {
-				c.Log.Errorf("adding field %q to group failed: %v", name, err)
-			}
+			grouper.Add(measurement, tags, timestamp, name, val)
 		} else {
-			if err := grouper.Add(measurement, tags, timestamp, name, value); err != nil {
-				c.Log.Errorf("adding field %q to group failed: %v", name, err)
-			}
+			grouper.Add(measurement, tags, timestamp, name, value)
 		}
 		return
 	}
@@ -702,12 +706,10 @@ func (c *CiscoTelemetryMDT) Address() net.Addr {
 func (c *CiscoTelemetryMDT) Stop() {
 	if c.grpcServer != nil {
 		// Stop server and terminate all running dialout routines
-		//nolint:errcheck,revive // we cannot do anything if the stopping fails
 		c.grpcServer.Stop()
 	}
 	if c.listener != nil {
-		//nolint:errcheck,revive // we cannot do anything if the closing fails
-		c.listener.Close()
+		c.listener.Close() //nolint:revive // we cannot do anything if the closing fails
 	}
 	c.wg.Wait()
 }
