@@ -1,13 +1,11 @@
 //go:generate ../../../tools/readme_config_includer/generator
 //go:build linux && amd64
-// +build linux,amd64
 
 package intel_pmu
 
 import (
 	_ "embed"
 	"fmt"
-	"io/ioutil"
 	"math"
 	"math/big"
 	"os"
@@ -36,7 +34,7 @@ type fileInfoProvider interface {
 type fileHelper struct{}
 
 func (fileHelper) readFile(path string) ([]byte, error) {
-	return ioutil.ReadFile(path)
+	return os.ReadFile(path)
 }
 
 func (fileHelper) lstat(path string) (os.FileInfo, error) {
@@ -221,14 +219,14 @@ func (i *IntelPMU) Gather(acc telegraf.Accumulator) error {
 	for id, m := range coreMetrics {
 		scaled := ia.EventScaledValue(m.values)
 		if !scaled.IsUint64() {
-			return fmt.Errorf("cannot process `%s` scaled value `%s`: exceeds uint64", m.name, scaled.String())
+			return fmt.Errorf("cannot process %q scaled value %q: exceeds uint64", m.name, scaled.String())
 		}
 		coreMetrics[id].scaled = scaled.Uint64()
 	}
 	for id, m := range uncoreMetrics {
 		scaled := ia.EventScaledValue(m.values)
 		if !scaled.IsUint64() {
-			return fmt.Errorf("cannot process `%s` scaled value `%s`: exceeds uint64", m.name, scaled.String())
+			return fmt.Errorf("cannot process %q scaled value %q: exceeds uint64", m.name, scaled.String())
 		}
 		uncoreMetrics[id].scaled = scaled.Uint64()
 	}
@@ -250,7 +248,7 @@ func (i *IntelPMU) Stop() {
 			}
 			err := event.Deactivate()
 			if err != nil {
-				i.Log.Warnf("failed to deactivate core event `%s`: %v", event, err)
+				i.Log.Warnf("failed to deactivate core event %q: %w", event, err)
 			}
 		}
 	}
@@ -265,7 +263,7 @@ func (i *IntelPMU) Stop() {
 				}
 				err := event.Deactivate()
 				if err != nil {
-					i.Log.Warnf("failed to deactivate uncore event `%s`: %v", event, err)
+					i.Log.Warnf("failed to deactivate uncore event %q: %w", event, err)
 				}
 			}
 		}
@@ -327,10 +325,10 @@ func multiplyAndAdd(factorA uint64, factorB uint64, sum uint64) (uint64, error)
 	bigB := new(big.Int).SetUint64(factorB)
 	activeEvents := new(big.Int).Mul(bigA, bigB)
 	if !activeEvents.IsUint64() {
-		return 0, fmt.Errorf("value `%s` cannot be represented as uint64", activeEvents.String())
+		return 0, fmt.Errorf("value %q cannot be represented as uint64", activeEvents.String())
 	}
 	if sum > math.MaxUint64-activeEvents.Uint64() {
-		return 0, fmt.Errorf("value `%s` exceeds uint64", new(big.Int).Add(activeEvents, new(big.Int).SetUint64(sum)))
+		return 0, fmt.Errorf("value %q exceeds uint64", new(big.Int).Add(activeEvents, new(big.Int).SetUint64(sum)))
 	}
 	sum += activeEvents.Uint64()
 	return sum, nil
@@ -342,11 +340,11 @@ func readMaxFD(reader fileInfoProvider) (uint64, error) {
 	}
 	buf, err := reader.readFile(fileMaxPath)
 	if err != nil {
-		return 0, fmt.Errorf("cannot open `%s` file: %v", fileMaxPath, err)
+		return 0, fmt.Errorf("cannot open file %q: %w", fileMaxPath, err)
 	}
 	max, err := strconv.ParseUint(strings.Trim(string(buf), "\n "), 10, 64)
 	if err != nil {
-		return 0, fmt.Errorf("cannot parse file content of `%s`: %v", fileMaxPath, err)
+		return 0, fmt.Errorf("cannot parse file content of %q: %w", fileMaxPath, err)
 	}
 	return max, nil
 }
@@ -364,16 +362,16 @@ func checkFiles(paths []string, fileInfo fileInfoProvider) error {
 		lInfo, err := fileInfo.lstat(path)
 		if err != nil {
 			if os.IsNotExist(err) {
-				return fmt.Errorf("file `%s` doesn't exist", path)
+				return fmt.Errorf("file %q doesn't exist", path)
 			}
-			return fmt.Errorf("cannot obtain file info of `%s`: %v", path, err)
+			return fmt.Errorf("cannot obtain file info of %q: %w", path, err)
 		}
 		mode := lInfo.Mode()
 		if mode&os.ModeSymlink != 0 {
-			return fmt.Errorf("file %s is a symlink", path)
+			return fmt.Errorf("file %q is a symlink", path)
 		}
 		if !mode.IsRegular() {
-			return fmt.Errorf("file `%s` doesn't point to a reagular file", path)
+			return fmt.Errorf("file %q doesn't point to a reagular file", path)
 		}
 	}
 	return nil
