@@ -1,20 +1,27 @@
+//go:generate ../../../tools/readme_config_includer/generator
 //go:build !solaris
-// +build !solaris
 
 package logparser
 
 import (
+	_ "embed"
 	"fmt"
 	"strings"
 	"sync"
 
 	"github.com/influxdata/tail"
+
 	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/internal/globpath"
+	"github.com/influxdata/telegraf/models"
 	"github.com/influxdata/telegraf/plugins/inputs"
 	"github.com/influxdata/telegraf/plugins/parsers"
+	"github.com/influxdata/telegraf/plugins/parsers/grok"
 )
 
+//go:embed sample.conf
+var sampleConfig string
+
 const (
 	defaultWatchMethod = "inotify"
 )
@@ -75,69 +82,10 @@ func NewLogParser() *LogParserPlugin {
 	}
 }
 
-const sampleConfig = `
-  ## Log files to parse.
-  ## These accept standard unix glob matching rules, but with the addition of
-  ## ** as a "super asterisk". ie:
-  ##   /var/log/**.log     -> recursively find all .log files in /var/log
-  ##   /var/log/*/*.log    -> find all .log files with a parent dir in /var/log
-  ##   /var/log/apache.log -> only tail the apache log file
-  files = ["/var/log/apache/access.log"]
-
-  ## Read files that currently exist from the beginning. Files that are created
-  ## while telegraf is running (and that match the "files" globs) will always
-  ## be read from the beginning.
-  from_beginning = false
-
-  ## Method used to watch for file updates.  Can be either "inotify" or "poll".
-  # watch_method = "inotify"
-
-  ## Parse logstash-style "grok" patterns:
-  [inputs.logparser.grok]
-    ## This is a list of patterns to check the given log file(s) for.
-    ## Note that adding patterns here increases processing time. The most
-    ## efficient configuration is to have one pattern per logparser.
-    ## Other common built-in patterns are:
-    ##   %{COMMON_LOG_FORMAT}   (plain apache & nginx access logs)
-    ##   %{COMBINED_LOG_FORMAT} (access logs + referrer & agent)
-    patterns = ["%{COMBINED_LOG_FORMAT}"]
-
-    ## Name of the outputted measurement name.
-    measurement = "apache_access_log"
-
-    ## Full path(s) to custom pattern files.
-    custom_pattern_files = []
-
-    ## Custom patterns can also be defined here. Put one pattern per line.
-    custom_patterns = '''
-    '''
-
-    ## Timezone allows you to provide an override for timestamps that
-    ## don't already include an offset
-    ## e.g. 04/06/2016 12:41:45 data one two 5.43µs
-    ##
-    ## Default: "" which renders UTC
-    ## Options are as follows:
-    ##   1. Local             -- interpret based on machine localtime
-    ##   2. "Canada/Eastern"  -- Unix TZ values like those found in https://en.wikipedia.org/wiki/List_of_tz_database_time_zones
-    ##   3. UTC               -- or blank/unspecified, will return timestamp in UTC
-    # timezone = "Canada/Eastern"
-
-	## When set to "disable", timestamp will not incremented if there is a
-	## duplicate.
-    # unique_timestamp = "auto"
-`
-
-// SampleConfig returns the sample configuration for the plugin
-func (l *LogParserPlugin) SampleConfig() string {
+func (*LogParserPlugin) SampleConfig() string {
 	return sampleConfig
 }
 
-// Description returns the human readable description for the plugin
-func (l *LogParserPlugin) Description() string {
-	return "Stream and parse log file(s)."
-}
-
 func (l *LogParserPlugin) Init() error {
 	l.Log.Warnf(`The logparser plugin is deprecated; please use the 'tail' input with the 'grok' data_format`)
 	return nil
@@ -168,22 +116,21 @@ func (l *LogParserPlugin) Start(acc telegraf.Accumulator) error {
 	}
 
 	// Looks for fields which implement LogParser interface
-	config := &parsers.Config{
-		MetricName:             mName,
-		GrokPatterns:           l.GrokConfig.Patterns,
-		GrokNamedPatterns:      l.GrokConfig.NamedPatterns,
-		GrokCustomPatterns:     l.GrokConfig.CustomPatterns,
-		GrokCustomPatternFiles: l.GrokConfig.CustomPatternFiles,
-		GrokTimezone:           l.GrokConfig.Timezone,
-		GrokUniqueTimestamp:    l.GrokConfig.UniqueTimestamp,
-		DataFormat:             "grok",
+	parser := grok.Parser{
+		Measurement:        mName,
+		Patterns:           l.GrokConfig.Patterns,
+		NamedPatterns:      l.GrokConfig.NamedPatterns,
+		CustomPatterns:     l.GrokConfig.CustomPatterns,
+		CustomPatternFiles: l.GrokConfig.CustomPatternFiles,
+		Timezone:           l.GrokConfig.Timezone,
+		UniqueTimestamp:    l.GrokConfig.UniqueTimestamp,
 	}
-
-	var err error
-	l.GrokParser, err = parsers.NewParser(config)
+	err := parser.Init()
 	if err != nil {
 		return err
 	}
+	l.GrokParser = &parser
+	models.SetLoggerOnPlugin(l.GrokParser, l.Log)
 
 	l.wg.Add(1)
 	go l.parser()
