@@ -1,6 +1,8 @@
+//go:generate ../../../tools/readme_config_includer/generator
 package snmp
 
 import (
+	_ "embed"
 	"encoding/binary"
 	"errors"
 	"fmt"
@@ -19,60 +21,27 @@ import (
 	"github.com/influxdata/telegraf/plugins/inputs"
 )
 
-const description = `Retrieves SNMP values from remote agents`
-const sampleConfig = `
-  ## Agent addresses to retrieve values from.
-  ##   format:  agents = ["<scheme://><hostname>:<port>"]
-  ##   scheme:  optional, either udp, udp4, udp6, tcp, tcp4, tcp6.
-  ##            default is udp
-  ##   port:    optional
-  ##   example: agents = ["udp://127.0.0.1:161"]
-  ##            agents = ["tcp://127.0.0.1:161"]
-  ##            agents = ["udp4://v4only-snmp-agent"]
-  agents = ["udp://127.0.0.1:161"]
+//go:embed sample.conf
+var sampleConfig string
 
-  ## Timeout for each request.
-  # timeout = "5s"
+type Translator interface {
+	SnmpTranslate(oid string) (
+		mibName string, oidNum string, oidText string,
+		conversion string,
+		err error,
+	)
 
-  ## SNMP version; can be 1, 2, or 3.
-  # version = 2
+	SnmpTable(oid string) (
+		mibName string, oidNum string, oidText string,
+		fields []Field,
+		err error,
+	)
 
-  ## Path to mib files
-  # path = ["/usr/share/snmp/mibs"]
-
-  ## Agent host tag; the tag used to reference the source host
-  # agent_host_tag = "agent_host"
-
-  ## SNMP community string.
-  # community = "public"
-
-  ## Number of retries to attempt.
-  # retries = 3
-
-  ## The GETBULK max-repetitions parameter.
-  # max_repetitions = 10
-
-  ## SNMPv3 authentication and encryption options.
-  ##
-  ## Security Name.
-  # sec_name = "myuser"
-  ## Authentication protocol; one of "MD5", "SHA", "SHA224", "SHA256", "SHA384", "SHA512" or "".
-  # auth_protocol = "MD5"
-  ## Authentication password.
-  # auth_password = "pass"
-  ## Security Level; one of "noAuthNoPriv", "authNoPriv", or "authPriv".
-  # sec_level = "authNoPriv"
-  ## Context Name.
-  # context_name = ""
-  ## Privacy protocol used for encrypted messages; one of "DES", "AES" or "".
-  # priv_protocol = ""
-  ## Privacy password used for encrypted messages.
-  # priv_password = ""
-  
-  ## Add fields and tables defining the variables you wish to collect.  This
-  ## example collects the system uptime and interface variables.  Reference the
-  ## full plugin documentation for configuration details.
-`
+	SnmpFormatEnum(oid string, value interface{}, full bool) (
+		formatted string,
+		err error,
+	)
+}
 
 // Snmp holds the configuration for the plugin.
 type Snmp struct {
@@ -90,30 +59,48 @@ type Snmp struct {
 	// Name & Fields are the elements of a Table.
 	// Telegraf chokes if we try to embed a Table. So instead we have to embed the
 	// fields of a Table, and construct a Table during runtime.
-	Name   string  // deprecated in 1.14; use name_override
+	Name   string  `toml:"name"`
 	Fields []Field `toml:"field"`
 
 	connectionCache []snmpConnection
 
 	Log telegraf.Logger `toml:"-"`
+
+	translator Translator
+}
+
+func (s *Snmp) SetTranslator(name string) {
+	s.Translator = name
+}
+
+func (*Snmp) SampleConfig() string {
+	return sampleConfig
 }
 
 func (s *Snmp) Init() error {
-	err := snmp.LoadMibsFromPath(s.Path, s.Log)
-	if err != nil {
-		return err
+	var err error
+	switch s.Translator {
+	case "gosmi":
+		s.translator, err = NewGosmiTranslator(s.Path, s.Log)
+		if err != nil {
+			return err
+		}
+	case "netsnmp":
+		s.translator = NewNetsnmpTranslator()
+	default:
+		return fmt.Errorf("invalid translator value")
 	}
 
 	s.connectionCache = make([]snmpConnection, len(s.Agents))
 
 	for i := range s.Tables {
-		if err := s.Tables[i].Init(); err != nil {
+		if err := s.Tables[i].Init(s.translator); err != nil {
 			return fmt.Errorf("initializing table %s: %w", s.Tables[i].Name, err)
 		}
 	}
 
 	for i := range s.Fields {
-		if err := s.Fields[i].init(); err != nil {
+		if err := s.Fields[i].init(s.translator); err != nil {
 			return fmt.Errorf("initializing field %s: %w", s.Fields[i].Name, err)
 		}
 	}
@@ -148,7 +135,7 @@ type Table struct {
 }
 
 // Init() builds & initializes the nested fields.
-func (t *Table) Init() error {
+func (t *Table) Init(tr Translator) error {
 	//makes sure oid or name is set in config file
 	//otherwise snmp will produce metrics with an empty name
 	if t.Oid == "" && t.Name == "" {
@@ -159,14 +146,14 @@ func (t *Table) Init() error {
 		return nil
 	}
 
-	if err := t.initBuild(); err != nil {
+	if err := t.initBuild(tr); err != nil {
 		return err
 	}
 
 	secondaryIndexTablePresent := false
 	// initialize all the nested fields
 	for i := range t.Fields {
-		if err := t.Fields[i].init(); err != nil {
+		if err := t.Fields[i].init(tr); err != nil {
 			return fmt.Errorf("initializing field %s: %w", t.Fields[i].Name, err)
 		}
 		if t.Fields[i].SecondaryIndexTable {
@@ -184,12 +171,12 @@ func (t *Table) Init() error {
 // initBuild initializes the table if it has an OID configured. If so, the
 // net-snmp tools will be used to look up the OID and auto-populate the table's
 // fields.
-func (t *Table) initBuild() error {
+func (t *Table) initBuild(tr Translator) error {
 	if t.Oid == "" {
 		return nil
 	}
 
-	_, _, oidText, fields, err := snmpTable(t.Oid)
+	_, _, oidText, fields, err := tr.SnmpTable(t.Oid)
 	if err != nil {
 		return err
 	}
@@ -232,6 +219,7 @@ type Field struct {
 	//  "int" will conver the value into an integer.
 	//  "hwaddr" will convert a 6-byte string to a MAC address.
 	//  "ipaddr" will convert the value to an IPv4 or IPv6 address.
+	//  "enum"/"enum(1)" will convert the value according to its syntax. (Only supported with gosmi translator)
 	Conversion string
 	// Translate tells if the value of the field should be snmptranslated
 	Translate bool
@@ -253,14 +241,14 @@ type Field struct {
 }
 
 // init() converts OID names to numbers, and sets the .Name attribute if unset.
-func (f *Field) init() error {
+func (f *Field) init(tr Translator) error {
 	if f.initialized {
 		return nil
 	}
 
 	// check if oid needs translation or name is not set
 	if strings.ContainsAny(f.Oid, ":abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ") || f.Name == "" {
-		_, oidNum, oidText, conversion, err := SnmpTranslate(f.Oid)
+		_, oidNum, oidText, conversion, err := tr.SnmpTranslate(f.Oid)
 		if err != nil {
 			return fmt.Errorf("translating: %w", err)
 		}
@@ -318,32 +306,6 @@ func (e *walkError) Unwrap() error {
 	return e.err
 }
 
-func init() {
-	inputs.Add("snmp", func() telegraf.Input {
-		return &Snmp{
-			Name: "snmp",
-			ClientConfig: snmp.ClientConfig{
-				Retries:        3,
-				MaxRepetitions: 10,
-				Timeout:        config.Duration(5 * time.Second),
-				Version:        2,
-				Path:           []string{"/usr/share/snmp/mibs"},
-				Community:      "public",
-			},
-		}
-	})
-}
-
-// SampleConfig returns the default configuration of the input.
-func (s *Snmp) SampleConfig() string {
-	return sampleConfig
-}
-
-// Description returns a one-sentence description on the input.
-func (s *Snmp) Description() string {
-	return description
-}
-
 // Gather retrieves all the configured fields and tables.
 // Any error encountered does not halt the process. The errors are accumulated
 // and returned at the end.
@@ -383,7 +345,7 @@ func (s *Snmp) Gather(acc telegraf.Accumulator) error {
 }
 
 func (s *Snmp) gatherTable(acc telegraf.Accumulator, gs snmpConnection, t Table, topTags map[string]string, walk bool) error {
-	rt, err := t.Build(gs, walk)
+	rt, err := t.Build(gs, walk, s.translator)
 	if err != nil {
 		return err
 	}
@@ -412,7 +374,7 @@ func (s *Snmp) gatherTable(acc telegraf.Accumulator, gs snmpConnection, t Table,
 }
 
 // Build retrieves all the fields specified in the table and constructs the RTable.
-func (t Table) Build(gs snmpConnection, walk bool) (*RTable, error) {
+func (t Table) Build(gs snmpConnection, walk bool, tr Translator) (*RTable, error) {
 	rows := map[string]RTableRow{}
 
 	//translation table for secondary index (when preforming join on two tables)
@@ -468,7 +430,7 @@ func (t Table) Build(gs snmpConnection, walk bool) (*RTable, error) {
 				}
 			} else if pkt != nil && len(pkt.Variables) > 0 && pkt.Variables[0].Type != gosnmp.NoSuchObject && pkt.Variables[0].Type != gosnmp.NoSuchInstance {
 				ent := pkt.Variables[0]
-				fv, err := fieldConvert(f.Conversion, ent.Value)
+				fv, err := fieldConvert(tr, f.Conversion, ent)
 				if err != nil {
 					return nil, fmt.Errorf("converting %q (OID %s) for field %s: %w", ent.Value, ent.Name, f.Name, err)
 				}
@@ -504,7 +466,7 @@ func (t Table) Build(gs snmpConnection, walk bool) (*RTable, error) {
 				// snmptranslate table field value here
 				if f.Translate {
 					if entOid, ok := ent.Value.(string); ok {
-						_, _, oidText, _, err := SnmpTranslate(entOid)
+						_, _, oidText, _, err := tr.SnmpTranslate(entOid)
 						if err == nil {
 							// If no error translating, the original value for ent.Value should be replaced
 							ent.Value = oidText
@@ -512,7 +474,7 @@ func (t Table) Build(gs snmpConnection, walk bool) (*RTable, error) {
 					}
 				}
 
-				fv, err := fieldConvert(f.Conversion, ent.Value)
+				fv, err := fieldConvert(tr, f.Conversion, ent)
 				if err != nil {
 					return &walkError{
 						msg: fmt.Sprintf("converting %q (OID %s) for field %s", ent.Value, ent.Name, f.Name),
@@ -603,6 +565,7 @@ type snmpConnection interface {
 	//BulkWalkAll(string) ([]gosnmp.SnmpPDU, error)
 	Walk(string, gosnmp.WalkFunc) error
 	Get(oids []string) (*gosnmp.SnmpPacket, error)
+	Reconnect() error
 }
 
 // getConnection creates a snmpConnection (*gosnmp.GoSNMP) object and caches the
@@ -611,6 +574,10 @@ type snmpConnection interface {
 // more than one goroutine.
 func (s *Snmp) getConnection(idx int) (snmpConnection, error) {
 	if gs := s.connectionCache[idx]; gs != nil {
+		if err := gs.Reconnect(); err != nil {
+			return gs, fmt.Errorf("reconnecting: %w", err)
+		}
+
 		return gs, nil
 	}
 
@@ -638,16 +605,17 @@ func (s *Snmp) getConnection(idx int) (snmpConnection, error) {
 }
 
 // fieldConvert converts from any type according to the conv specification
-func fieldConvert(conv string, v interface{}) (interface{}, error) {
+func fieldConvert(tr Translator, conv string, ent gosnmp.SnmpPDU) (v interface{}, err error) {
 	if conv == "" {
-		if bs, ok := v.([]byte); ok {
+		if bs, ok := ent.Value.([]byte); ok {
 			return string(bs), nil
 		}
-		return v, nil
+		return ent.Value, nil
 	}
 
 	var d int
 	if _, err := fmt.Sscanf(conv, "float(%d)", &d); err == nil || conv == "float" {
+		v = ent.Value
 		switch vt := v.(type) {
 		case float32:
 			v = float64(vt) / math.Pow10(d)
@@ -684,6 +652,7 @@ func fieldConvert(conv string, v interface{}) (interface{}, error) {
 	}
 
 	if conv == "int" {
+		v = ent.Value
 		switch vt := v.(type) {
 		case float32:
 			v = int64(vt)
@@ -718,7 +687,7 @@ func fieldConvert(conv string, v interface{}) (interface{}, error) {
 	}
 
 	if conv == "hwaddr" {
-		switch vt := v.(type) {
+		switch vt := ent.Value.(type) {
 		case string:
 			v = net.HardwareAddr(vt).String()
 		case []byte:
@@ -734,9 +703,9 @@ func fieldConvert(conv string, v interface{}) (interface{}, error) {
 		endian := split[1]
 		bit := split[2]
 
-		bv, ok := v.([]byte)
+		bv, ok := ent.Value.([]byte)
 		if !ok {
-			return v, nil
+			return ent.Value, nil
 		}
 
 		switch endian {
@@ -772,7 +741,7 @@ func fieldConvert(conv string, v interface{}) (interface{}, error) {
 	if conv == "ipaddr" {
 		var ipbs []byte
 
-		switch vt := v.(type) {
+		switch vt := ent.Value.(type) {
 		case string:
 			ipbs = []byte(vt)
 		case []byte:
@@ -791,94 +760,29 @@ func fieldConvert(conv string, v interface{}) (interface{}, error) {
 		return v, nil
 	}
 
-	return nil, fmt.Errorf("invalid conversion type '%s'", conv)
-}
-
-type snmpTableCache struct {
-	mibName string
-	oidNum  string
-	oidText string
-	fields  []Field
-	err     error
-}
-
-var snmpTableCaches map[string]snmpTableCache
-var snmpTableCachesLock sync.Mutex
-
-// snmpTable resolves the given OID as a table, providing information about the
-// table and fields within.
-//nolint:revive //Too many return variable but necessary
-func snmpTable(oid string) (mibName string, oidNum string, oidText string, fields []Field, err error) {
-	snmpTableCachesLock.Lock()
-	if snmpTableCaches == nil {
-		snmpTableCaches = map[string]snmpTableCache{}
+	if conv == "enum" {
+		return tr.SnmpFormatEnum(ent.Name, ent.Value, false)
 	}
 
-	var stc snmpTableCache
-	var ok bool
-	if stc, ok = snmpTableCaches[oid]; !ok {
-		stc.mibName, stc.oidNum, stc.oidText, stc.fields, stc.err = snmpTableCall(oid)
-		snmpTableCaches[oid] = stc
+	if conv == "enum(1)" {
+		return tr.SnmpFormatEnum(ent.Name, ent.Value, true)
 	}
 
-	snmpTableCachesLock.Unlock()
-	return stc.mibName, stc.oidNum, stc.oidText, stc.fields, stc.err
+	return nil, fmt.Errorf("invalid conversion type %q", conv)
 }
 
-//nolint:revive //Too many return variable but necessary
-func snmpTableCall(oid string) (mibName string, oidNum string, oidText string, fields []Field, err error) {
-	mibName, oidNum, oidText, _, err = SnmpTranslate(oid)
-	if err != nil {
-		return "", "", "", nil, fmt.Errorf("translating: %w", err)
-	}
-
-	mibPrefix := mibName + "::"
-
-	col, tagOids, err := snmp.GetIndex(oidNum, mibPrefix)
-
-	for _, c := range col {
-		_, isTag := tagOids[mibPrefix+c]
-		fields = append(fields, Field{Name: c, Oid: mibPrefix + c, IsTag: isTag})
-	}
-
-	return mibName, oidNum, oidText, fields, err
-}
-
-type snmpTranslateCache struct {
-	mibName    string
-	oidNum     string
-	oidText    string
-	conversion string
-	err        error
-}
-
-var snmpTranslateCachesLock sync.Mutex
-var snmpTranslateCaches map[string]snmpTranslateCache
-
-// snmpTranslate resolves the given OID.
-//nolint:revive //Too many return variable but necessary
-func SnmpTranslate(oid string) (mibName string, oidNum string, oidText string, conversion string, err error) {
-	snmpTranslateCachesLock.Lock()
-	if snmpTranslateCaches == nil {
-		snmpTranslateCaches = map[string]snmpTranslateCache{}
-	}
-
-	var stc snmpTranslateCache
-	var ok bool
-	if stc, ok = snmpTranslateCaches[oid]; !ok {
-		// This will result in only one call to snmptranslate running at a time.
-		// We could speed it up by putting a lock in snmpTranslateCache and then
-		// returning it immediately, and multiple callers would then release the
-		// snmpTranslateCachesLock and instead wait on the individual
-		// snmpTranslation.Lock to release. But I don't know that the extra complexity
-		// is worth it. Especially when it would slam the system pretty hard if lots
-		// of lookups are being performed.
-
-		stc.mibName, stc.oidNum, stc.oidText, stc.conversion, stc.err = snmp.SnmpTranslateCall(oid)
-		snmpTranslateCaches[oid] = stc
-	}
-
-	snmpTranslateCachesLock.Unlock()
-
-	return stc.mibName, stc.oidNum, stc.oidText, stc.conversion, stc.err
+func init() {
+	inputs.Add("snmp", func() telegraf.Input {
+		return &Snmp{
+			Name: "snmp",
+			ClientConfig: snmp.ClientConfig{
+				Retries:        3,
+				MaxRepetitions: 10,
+				Timeout:        config.Duration(5 * time.Second),
+				Version:        2,
+				Path:           []string{"/usr/share/snmp/mibs"},
+				Community:      "public",
+			},
+		}
+	})
 }
