@@ -1,17 +1,21 @@
+//go:generate ../../../tools/readme_config_includer/generator
 package statsd
 
 import (
 	"bufio"
 	"bytes"
-	"errors"
+	_ "embed"
 	"fmt"
 	"net"
+	"regexp"
 	"sort"
 	"strconv"
 	"strings"
 	"sync"
 	"time"
 
+	"github.com/pkg/errors"
+
 	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/config"
 	"github.com/influxdata/telegraf/internal"
@@ -20,6 +24,9 @@ import (
 	"github.com/influxdata/telegraf/selfstat"
 )
 
+//go:embed sample.conf
+var sampleConfig string
+
 const (
 	// UDPMaxPacketSize is the UDP packet limit, see
 	// https://en.wikipedia.org/wiki/User_Datagram_Protocol#Packet_structure
@@ -35,6 +42,21 @@ const (
 	parserGoRoutines = 5
 )
 
+var errParsing = errors.New("error parsing statsd line")
+
+// Number will get parsed as an int or float depending on what is passed
+type Number float64
+
+func (n *Number) UnmarshalTOML(b []byte) error {
+	value, err := strconv.ParseFloat(string(b), 64)
+	if err != nil {
+		return err
+	}
+
+	*n = Number(value)
+	return nil
+}
+
 // Statsd allows the importing of statsd and dogstatsd data.
 type Statsd struct {
 	// Protocol used on listener - udp or tcp
@@ -49,20 +71,20 @@ type Statsd struct {
 
 	// Percentiles specifies the percentiles that will be calculated for timing
 	// and histogram stats.
-	Percentiles     []float64
+	Percentiles     []Number
 	PercentileLimit int
 
 	DeleteGauges   bool
 	DeleteCounters bool
 	DeleteSets     bool
 	DeleteTimings  bool
-	ConvertNames   bool
+	ConvertNames   bool `toml:"convert_names" deprecated:"0.12.0;2.0.0;use 'metric_separator' instead"`
 
 	// MetricSeparator is the separator between parts of the metric name.
 	MetricSeparator string
 	// This flag enables parsing of tags in the dogstatsd extension to the
 	// statsd protocol (http://docs.datadoghq.com/guides/dogstatsd/)
-	ParseDataDogTags bool // depreciated in 1.10; use datadog_extensions
+	ParseDataDogTags bool `toml:"parse_data_dog_tags" deprecated:"1.10.0;use 'datadog_extensions' instead"`
 
 	// Parses extensions to statsd in the datadog statsd format
 	// currently supports metrics and datadog tags.
@@ -78,10 +100,12 @@ type Statsd struct {
 	// we now always create 1 max size buffer and then copy only what we need
 	// into the in channel
 	// see https://github.com/influxdata/telegraf/pull/992
-	UDPPacketSize int `toml:"udp_packet_size"`
+	UDPPacketSize int `toml:"udp_packet_size" deprecated:"0.12.1;2.0.0;option is ignored"`
 
 	ReadBufferSize int `toml:"read_buffer_size"`
 
+	SanitizeNamesMethod string `toml:"sanitize_name_method"`
+
 	sync.Mutex
 	// Lock for preventing a data race during resource cleanup
 	cleanup sync.Mutex
@@ -125,7 +149,7 @@ type Statsd struct {
 	// Max duration for each metric to stay cached without being updated.
 	MaxTTL config.Duration `toml:"max_ttl"`
 
-	graphiteParser *graphite.GraphiteParser
+	graphiteParser *graphite.Parser
 
 	acc telegraf.Accumulator
 
@@ -200,77 +224,7 @@ type cacheddistributions struct {
 	tags  map[string]string
 }
 
-func (s *Statsd) Description() string {
-	return "Statsd UDP/TCP Server"
-}
-
-const sampleConfig = `
-  ## Protocol, must be "tcp", "udp", "udp4" or "udp6" (default=udp)
-  protocol = "udp"
-
-  ## MaxTCPConnection - applicable when protocol is set to tcp (default=250)
-  max_tcp_connections = 250
-
-  ## Enable TCP keep alive probes (default=false)
-  tcp_keep_alive = false
-
-  ## Specifies the keep-alive period for an active network connection.
-  ## Only applies to TCP sockets and will be ignored if tcp_keep_alive is false.
-  ## Defaults to the OS configuration.
-  # tcp_keep_alive_period = "2h"
-
-  ## Address and port to host UDP listener on
-  service_address = ":8125"
-
-  ## The following configuration options control when telegraf clears it's cache
-  ## of previous values. If set to false, then telegraf will only clear it's
-  ## cache when the daemon is restarted.
-  ## Reset gauges every interval (default=true)
-  delete_gauges = true
-  ## Reset counters every interval (default=true)
-  delete_counters = true
-  ## Reset sets every interval (default=true)
-  delete_sets = true
-  ## Reset timings & histograms every interval (default=true)
-  delete_timings = true
-
-  ## Percentiles to calculate for timing & histogram stats
-  percentiles = [50.0, 90.0, 99.0, 99.9, 99.95, 100.0]
-
-  ## separator to use between elements of a statsd metric
-  metric_separator = "_"
-
-  ## Parses tags in the datadog statsd format
-  ## http://docs.datadoghq.com/guides/dogstatsd/
-  parse_data_dog_tags = false
-
-  ## Parses datadog extensions to the statsd format
-  datadog_extensions = false
-
-  ## Parses distributions metric as specified in the datadog statsd format
-  ## https://docs.datadoghq.com/developers/metrics/types/?tab=distribution#definition
-  datadog_distributions = false
-
-  ## Statsd data translation templates, more info can be read here:
-  ## https://github.com/influxdata/telegraf/blob/master/docs/TEMPLATE_PATTERN.md
-  # templates = [
-  #     "cpu.* measurement*"
-  # ]
-
-  ## Number of UDP messages allowed to queue up, once filled,
-  ## the statsd server will start dropping packets
-  allowed_pending_messages = 10000
-
-  ## Number of timing/histogram values to track per-measurement in the
-  ## calculation of percentiles. Raising this limit increases the accuracy
-  ## of percentiles but also increases the memory usage and cpu time.
-  percentile_limit = 1000
-
-  ## Max duration (TTL) for each metric to stay cached/reported without being updated.
-  #max_ttl = "1000h"
-`
-
-func (s *Statsd) SampleConfig() string {
+func (*Statsd) SampleConfig() string {
 	return sampleConfig
 }
 
@@ -298,6 +252,7 @@ func (s *Statsd) Gather(acc telegraf.Accumulator) error {
 				prefix = fieldName + "_"
 			}
 			fields[prefix+"mean"] = stats.Mean()
+			fields[prefix+"median"] = stats.Median()
 			fields[prefix+"stddev"] = stats.Stddev()
 			fields[prefix+"sum"] = stats.Sum()
 			fields[prefix+"upper"] = stats.Upper()
@@ -305,7 +260,7 @@ func (s *Statsd) Gather(acc telegraf.Accumulator) error {
 			fields[prefix+"count"] = stats.Count()
 			for _, percentile := range s.Percentiles {
 				name := fmt.Sprintf("%s%v_percentile", prefix, percentile)
-				fields[name] = stats.Percentile(percentile)
+				fields[name] = stats.Percentile(float64(percentile))
 			}
 		}
 
@@ -348,7 +303,6 @@ func (s *Statsd) Gather(acc telegraf.Accumulator) error {
 func (s *Statsd) Start(ac telegraf.Accumulator) error {
 	if s.ParseDataDogTags {
 		s.DataDogExtensions = true
-		s.Log.Warn("'parse_data_dog_tags' config option is deprecated, please use 'datadog_extensions' instead")
 	}
 
 	s.acc = ac
@@ -390,10 +344,6 @@ func (s *Statsd) Start(ac telegraf.Accumulator) error {
 		s.accept <- true
 	}
 
-	if s.ConvertNames {
-		s.Log.Warn("'convert_names' config option is deprecated, please use 'metric_separator' instead")
-	}
-
 	if s.MetricSeparator == "" {
 		s.MetricSeparator = defaultSeparator
 	}
@@ -455,7 +405,7 @@ func (s *Statsd) Start(ac telegraf.Accumulator) error {
 	return nil
 }
 
-// tcpListen() starts listening for udp packets on the configured port.
+// tcpListen() starts listening for TCP packets on the configured port.
 func (s *Statsd) tcpListen(listener *net.TCPListener) error {
 	for {
 		select {
@@ -485,7 +435,11 @@ func (s *Statsd) tcpListen(listener *net.TCPListener) error {
 				// not over connection limit, handle the connection properly.
 				s.wg.Add(1)
 				// generate a random id for this TCPConn
-				id := internal.RandomString(6)
+				id, err := internal.RandomString(6)
+				if err != nil {
+					return err
+				}
+
 				s.remember(id, conn)
 				go s.handler(conn, id)
 			default:
@@ -496,7 +450,7 @@ func (s *Statsd) tcpListen(listener *net.TCPListener) error {
 	}
 }
 
-// udpListen starts listening for udp packets on the configured port.
+// udpListen starts listening for UDP packets on the configured port.
 func (s *Statsd) udpListen(conn *net.UDPConn) error {
 	if s.ReadBufferSize > 0 {
 		if err := s.UDPlistener.SetReadBuffer(s.ReadBufferSize); err != nil {
@@ -516,7 +470,7 @@ func (s *Statsd) udpListen(conn *net.UDPConn) error {
 					s.Log.Errorf("Error reading: %s", err.Error())
 					continue
 				}
-				return err
+				return nil
 			}
 			s.UDPPacketsRecv.Incr(1)
 			s.UDPBytesRecv.Incr(int64(n))
@@ -564,11 +518,19 @@ func (s *Statsd) parser() error {
 				case line == "":
 				case s.DataDogExtensions && strings.HasPrefix(line, "_e"):
 					if err := s.parseEventMessage(in.Time, line, in.Addr); err != nil {
-						return err
+						// Log the line causing the parsing error and continue
+						// with the next line to not stop the whole gathering
+						// process.
+						s.Log.Errorf("Parsing line failed: %v", err)
+						s.Log.Debugf("  line was: %s", line)
 					}
 				default:
 					if err := s.parseStatsdLine(line); err != nil {
-						return err
+						if errors.Cause(err) != errParsing {
+							// Ignore parsing errors but error out on
+							// everything else...
+							return err
+						}
 					}
 				}
 			}
@@ -605,7 +567,7 @@ func (s *Statsd) parseStatsdLine(line string) error {
 	bits := strings.Split(line, ":")
 	if len(bits) < 2 {
 		s.Log.Errorf("Splitting ':', unable to parse metric: %s", line)
-		return errors.New("error Parsing statsd line")
+		return errParsing
 	}
 
 	// Extract bucket name from individual metric bits
@@ -621,7 +583,7 @@ func (s *Statsd) parseStatsdLine(line string) error {
 		pipesplit := strings.Split(bit, "|")
 		if len(pipesplit) < 2 {
 			s.Log.Errorf("Splitting '|', unable to parse metric: %s", line)
-			return errors.New("error parsing statsd line")
+			return errParsing
 		} else if len(pipesplit) > 2 {
 			sr := pipesplit[2]
 
@@ -645,14 +607,14 @@ func (s *Statsd) parseStatsdLine(line string) error {
 			m.mtype = pipesplit[1]
 		default:
 			s.Log.Errorf("Metric type %q unsupported", pipesplit[1])
-			return errors.New("error parsing statsd line")
+			return errParsing
 		}
 
 		// Parse the value
 		if strings.HasPrefix(pipesplit[0], "-") || strings.HasPrefix(pipesplit[0], "+") {
 			if m.mtype != "g" && m.mtype != "c" {
 				s.Log.Errorf("+- values are only supported for gauges & counters, unable to parse metric: %s", line)
-				return errors.New("error parsing statsd line")
+				return errParsing
 			}
 			m.additive = true
 		}
@@ -662,7 +624,7 @@ func (s *Statsd) parseStatsdLine(line string) error {
 			v, err := strconv.ParseFloat(pipesplit[0], 64)
 			if err != nil {
 				s.Log.Errorf("Parsing value to float64, unable to parse metric: %s", line)
-				return errors.New("error parsing statsd line")
+				return errParsing
 			}
 			m.floatvalue = v
 		case "c":
@@ -672,7 +634,7 @@ func (s *Statsd) parseStatsdLine(line string) error {
 				v2, err2 := strconv.ParseFloat(pipesplit[0], 64)
 				if err2 != nil {
 					s.Log.Errorf("Parsing value to int64, unable to parse metric: %s", line)
-					return errors.New("error parsing statsd line")
+					return errParsing
 				}
 				v = int64(v2)
 			}
@@ -726,10 +688,10 @@ func (s *Statsd) parseStatsdLine(line string) error {
 // config file. If there is a match, it will parse the name of the metric and
 // map of tags.
 // Return values are (<name>, <field>, <tags>)
-func (s *Statsd) parseName(bucket string) (string, string, map[string]string) {
+func (s *Statsd) parseName(bucket string) (name string, field string, tags map[string]string) {
 	s.Lock()
 	defer s.Unlock()
-	tags := make(map[string]string)
+	tags = make(map[string]string)
 
 	bucketparts := strings.Split(bucket, ",")
 	// Parse out any tags in the bucket
@@ -742,14 +704,25 @@ func (s *Statsd) parseName(bucket string) (string, string, map[string]string) {
 		}
 	}
 
-	var field string
-	name := bucketparts[0]
+	name = bucketparts[0]
+	switch s.SanitizeNamesMethod {
+	case "":
+	case "upstream":
+		whitespace := regexp.MustCompile(`\s+`)
+		name = whitespace.ReplaceAllString(name, "_")
+		name = strings.ReplaceAll(name, "/", "-")
+		allowedChars := regexp.MustCompile(`[^a-zA-Z_\-0-9\.;=]`)
+		name = allowedChars.ReplaceAllString(name, "")
+	default:
+		s.Log.Errorf("Unknown sanitizae name method: %s", s.SanitizeNamesMethod)
+	}
 
 	p := s.graphiteParser
 	var err error
 
 	if p == nil || s.graphiteParser.Separator != s.MetricSeparator {
-		p, err = graphite.NewGraphiteParser(s.MetricSeparator, s.Templates, nil)
+		p = &graphite.Parser{Separator: s.MetricSeparator, Templates: s.Templates}
+		err = p.Init()
 		s.graphiteParser = p
 	}
 
@@ -759,8 +732,8 @@ func (s *Statsd) parseName(bucket string) (string, string, map[string]string) {
 	}
 
 	if s.ConvertNames {
-		name = strings.Replace(name, ".", "_", -1)
-		name = strings.Replace(name, "-", "__", -1)
+		name = strings.ReplaceAll(name, ".", "_")
+		name = strings.ReplaceAll(name, "-", "__")
 	}
 	if field == "" {
 		field = defaultFieldName
@@ -770,16 +743,20 @@ func (s *Statsd) parseName(bucket string) (string, string, map[string]string) {
 }
 
 // Parse the key,value out of a string that looks like "key=value"
-func parseKeyValue(keyvalue string) (string, string) {
-	var key, val string
-
-	split := strings.Split(keyvalue, "=")
+func parseKeyValue(keyValue string) (key string, val string) {
+	split := strings.Split(keyValue, "=")
 	// Must be exactly 2 to get anything meaningful out of them
 	if len(split) == 2 {
 		key = split[0]
 		val = split[1]
 	} else if len(split) == 1 {
 		val = split[0]
+	} else if len(split) > 2 {
+		// fix: https://github.com/influxdata/telegraf/issues/10113
+		// fix: value has "=" parse error
+		// uri=/service/endpoint?sampleParam={paramValue} parse value key="uri", val="/service/endpoint?sampleParam\={paramValue}"
+		key = split[0]
+		val = strings.Join(split[1:], "=")
 	}
 
 	return key, val
@@ -899,10 +876,7 @@ func (s *Statsd) handler(conn *net.TCPConn, id string) {
 	// connection cleanup function
 	defer func() {
 		s.wg.Done()
-
-		// Ignore the returned error as we cannot do anything about it anyway
-		//nolint:errcheck,revive
-		conn.Close()
+		conn.Close() //nolint:revive // Ignore the returned error as we cannot do anything about it anyway
 
 		// Add one connection potential back to channel when this one closes
 		s.accept <- true
@@ -934,11 +908,8 @@ func (s *Statsd) handler(conn *net.TCPConn, id string) {
 
 			b := s.bufPool.Get().(*bytes.Buffer)
 			b.Reset()
-			// Writes to a bytes buffer always succeed, so do not check the errors here
-			//nolint:errcheck,revive
-			b.Write(scanner.Bytes())
-			//nolint:errcheck,revive
-			b.WriteByte('\n')
+			b.Write(scanner.Bytes()) //nolint:revive // Writes to a bytes buffer always succeed, so do not check the errors here
+			b.WriteByte('\n')        //nolint:revive // Writes to a bytes buffer always succeed, so do not check the errors here
 
 			select {
 			case s.in <- input{Buffer: b, Time: time.Now(), Addr: remoteIP}:
@@ -956,9 +927,7 @@ func (s *Statsd) handler(conn *net.TCPConn, id string) {
 
 // refuser refuses a TCP connection
 func (s *Statsd) refuser(conn *net.TCPConn) {
-	// Ignore the returned error as we cannot do anything about it anyway
-	//nolint:errcheck,revive
-	conn.Close()
+	conn.Close() //nolint:revive // Ignore the returned error as we cannot do anything about it anyway
 	s.Log.Infof("Refused TCP Connection from %s", conn.RemoteAddr())
 	s.Log.Warn("Maximum TCP Connections reached, you may want to adjust max_tcp_connections")
 }
@@ -982,13 +951,9 @@ func (s *Statsd) Stop() {
 	s.Log.Infof("Stopping the statsd service")
 	close(s.done)
 	if s.isUDP() {
-		// Ignore the returned error as we cannot do anything about it anyway
-		//nolint:errcheck,revive
-		s.UDPlistener.Close()
+		s.UDPlistener.Close() //nolint:revive // Ignore the returned error as we cannot do anything about it anyway
 	} else {
-		// Ignore the returned error as we cannot do anything about it anyway
-		//nolint:errcheck,revive
-		s.TCPlistener.Close()
+		s.TCPlistener.Close() //nolint:revive // Ignore the returned error as we cannot do anything about it anyway
 		// Close all open TCP connections
 		//  - get all conns from the s.conns map and put into slice
 		//  - this is so the forget() function doesnt conflict with looping
@@ -1000,9 +965,7 @@ func (s *Statsd) Stop() {
 		}
 		s.cleanup.Unlock()
 		for _, conn := range conns {
-			// Ignore the returned error as we cannot do anything about it anyway
-			//nolint:errcheck,revive
-			conn.Close()
+			conn.Close() //nolint:revive // Ignore the returned error as we cannot do anything about it anyway
 		}
 	}
 	s.Unlock()
@@ -1066,6 +1029,7 @@ func init() {
 			DeleteGauges:           true,
 			DeleteSets:             true,
 			DeleteTimings:          true,
+			SanitizeNamesMethod:    "",
 		}
 	})
 }
