@@ -5,25 +5,26 @@ import (
 	"path/filepath"
 	"strings"
 
-	"github.com/influxdata/telegraf"
-	"github.com/influxdata/telegraf/internal"
-
 	"github.com/shirou/gopsutil/v3/cpu"
 	"github.com/shirou/gopsutil/v3/disk"
 	"github.com/shirou/gopsutil/v3/host"
 	"github.com/shirou/gopsutil/v3/mem"
 	"github.com/shirou/gopsutil/v3/net"
+
+	"github.com/influxdata/telegraf"
+	"github.com/influxdata/telegraf/internal"
 )
 
 type PS interface {
 	CPUTimes(perCPU, totalCPU bool) ([]cpu.TimesStat, error)
-	DiskUsage(mountPointFilter []string, fstypeExclude []string) ([]*disk.UsageStat, []*disk.PartitionStat, error)
+	DiskUsage(mountPointFilter []string, mountOptsExclude []string, fstypeExclude []string) ([]*disk.UsageStat, []*disk.PartitionStat, error)
 	NetIO() ([]net.IOCountersStat, error)
 	NetProto() ([]net.ProtoCountersStat, error)
 	DiskIO(names []string) (map[string]disk.IOCountersStat, error)
 	VMStat() (*mem.VirtualMemoryStat, error)
 	SwapStat() (*mem.SwapMemoryStat, error)
 	NetConnections() ([]net.ConnectionStat, error)
+	NetConntrack(perCPU bool) ([]net.ConntrackStat, error)
 	Temperature() ([]host.TemperatureStat, error)
 }
 
@@ -91,6 +92,7 @@ func newSet() *set {
 
 func (s *SystemPS) DiskUsage(
 	mountPointFilter []string,
+	mountOptsExclude []string,
 	fstypeExclude []string,
 ) ([]*disk.UsageStat, []*disk.PartitionStat, error) {
 	parts, err := s.Partitions(true)
@@ -102,6 +104,10 @@ func (s *SystemPS) DiskUsage(
 	for _, filter := range mountPointFilter {
 		mountPointFilterSet.add(filter)
 	}
+	mountOptFilterSet := newSet()
+	for _, filter := range mountOptsExclude {
+		mountOptFilterSet.add(filter)
+	}
 	fstypeExcludeSet := newSet()
 	for _, filter := range fstypeExclude {
 		fstypeExcludeSet.add(filter)
@@ -120,9 +126,15 @@ func (s *SystemPS) DiskUsage(
 	var partitions []*disk.PartitionStat
 	hostMountPrefix := s.OSGetenv("HOST_MOUNT_PREFIX")
 
+partitionRange:
 	for i := range parts {
 		p := parts[i]
 
+		for _, o := range p.Opts {
+			if !mountOptFilterSet.empty() && mountOptFilterSet.has(o) {
+				continue partitionRange
+			}
+		}
 		// If there is a filter set and if the mount point is not a
 		// member of the filter set, don't gather info on it.
 		if !mountPointFilterSet.empty() && !mountPointFilterSet.has(p.Mountpoint) {
@@ -180,9 +192,13 @@ func (s *SystemPS) NetConnections() ([]net.ConnectionStat, error) {
 	return net.Connections("all")
 }
 
+func (s *SystemPS) NetConntrack(perCPU bool) ([]net.ConntrackStat, error) {
+	return net.ConntrackStats(perCPU)
+}
+
 func (s *SystemPS) DiskIO(names []string) (map[string]disk.IOCountersStat, error) {
 	m, err := disk.IOCounters(names...)
-	if err == internal.ErrorNotImplemented {
+	if err == internal.ErrNotImplemented {
 		return nil, nil
 	}
 
@@ -198,14 +214,7 @@ func (s *SystemPS) SwapStat() (*mem.SwapMemoryStat, error) {
 }
 
 func (s *SystemPS) Temperature() ([]host.TemperatureStat, error) {
-	temp, err := host.SensorsTemperatures()
-	if err != nil {
-		_, ok := err.(*host.Warnings)
-		if !ok {
-			return temp, err
-		}
-	}
-	return temp, nil
+	return host.SensorsTemperatures()
 }
 
 func (s *SystemPSDisk) Partitions(all bool) ([]disk.PartitionStat, error) {
