@@ -3,12 +3,13 @@ package kafka
 
 import (
 	_ "embed"
+	"errors"
 	"fmt"
 	"strings"
 	"time"
 
 	"github.com/Shopify/sarama"
-	"github.com/gofrs/uuid"
+	"github.com/gofrs/uuid/v5"
 
 	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/plugins/common/kafka"
@@ -17,8 +18,6 @@ import (
 	"github.com/influxdata/telegraf/plugins/serializers"
 )
 
-// DO NOT REMOVE THE NEXT TWO LINES! This is required to embed the sampleConfig data.
-//
 //go:embed sample.conf
 var sampleConfig string
 
@@ -51,6 +50,8 @@ type Kafka struct {
 
 	kafka.WriteConfig
 
+	kafka.Logger
+
 	Log telegraf.Logger `toml:"-"`
 
 	saramaConfig *sarama.Config
@@ -66,25 +67,6 @@ type TopicSuffix struct {
 	Separator string   `toml:"separator"`
 }
 
-// DebugLogger logs messages from sarama at the debug level.
-type DebugLogger struct {
-	Log telegraf.Logger
-}
-
-func (l *DebugLogger) Print(v ...interface{}) {
-	args := make([]interface{}, 0, len(v)+1)
-	args = append(append(args, "[sarama] "), v...)
-	l.Log.Debug(args...)
-}
-
-func (l *DebugLogger) Printf(format string, v ...interface{}) {
-	l.Log.Debugf("[sarama] "+format, v...)
-}
-
-func (l *DebugLogger) Println(v ...interface{}) {
-	l.Print(v)
-}
-
 func ValidateTopicSuffixMethod(method string) error {
 	for _, validMethod := range ValidTopicSuffixMethods {
 		if method == validMethod {
@@ -139,7 +121,7 @@ func (k *Kafka) SetSerializer(serializer serializers.Serializer) {
 }
 
 func (k *Kafka) Init() error {
-	sarama.Logger = &DebugLogger{Log: k.Log}
+	k.SetLogger()
 
 	err := ValidateTopicSuffixMethod(k.TopicSuffix.Method)
 	if err != nil {
@@ -147,7 +129,7 @@ func (k *Kafka) Init() error {
 	}
 	config := sarama.NewConfig()
 
-	if err := k.SetConfig(config); err != nil {
+	if err := k.SetConfig(config, k.Log); err != nil {
 		return err
 	}
 
@@ -165,7 +147,7 @@ func (k *Kafka) Init() error {
 
 		dialer, err := k.Socks5ProxyConfig.GetDialer()
 		if err != nil {
-			return fmt.Errorf("connecting to proxy server failed: %s", err)
+			return fmt.Errorf("connecting to proxy server failed: %w", err)
 		}
 		config.Net.Proxy.Dialer = dialer
 	}
@@ -228,7 +210,7 @@ func (k *Kafka) Write(metrics []telegraf.Metric) error {
 
 		key, err := k.routingKey(metric)
 		if err != nil {
-			return fmt.Errorf("could not generate routing key: %v", err)
+			return fmt.Errorf("could not generate routing key: %w", err)
 		}
 
 		if key != "" {
@@ -240,14 +222,18 @@ func (k *Kafka) Write(metrics []telegraf.Metric) error {
 	err := k.producer.SendMessages(msgs)
 	if err != nil {
 		// We could have many errors, return only the first encountered.
-		if errs, ok := err.(sarama.ProducerErrors); ok {
+		var errs sarama.ProducerErrors
+		if errors.As(err, &errs) {
 			for _, prodErr := range errs {
-				if prodErr.Err == sarama.ErrMessageSizeTooLarge {
+				if errors.Is(prodErr.Err, sarama.ErrMessageSizeTooLarge) {
 					k.Log.Error("Message too large, consider increasing `max_message_bytes`; dropping batch")
 					return nil
 				}
-				if prodErr.Err == sarama.ErrInvalidTimestamp {
-					k.Log.Error("The timestamp of the message is out of acceptable range, consider increasing broker `message.timestamp.difference.max.ms`; dropping batch")
+				if errors.Is(prodErr.Err, sarama.ErrInvalidTimestamp) {
+					k.Log.Error(
+						"The timestamp of the message is out of acceptable range, consider increasing broker `message.timestamp.difference.max.ms`; " +
+							"dropping batch",
+					)
 					return nil
 				}
 				return prodErr //nolint:staticcheck // Return first error encountered
