@@ -92,18 +92,18 @@ func (l *Logzio) Write(metrics []telegraf.Metric) error {
 
 		serialized, err := json.Marshal(m)
 		if err != nil {
-			return fmt.Errorf("unable to marshal metric, %s", err.Error())
+			return fmt.Errorf("unable to marshal metric: %w", err)
 		}
 
 		_, err = gz.Write(append(serialized, '\n'))
 		if err != nil {
-			return fmt.Errorf("unable to write gzip meric, %s", err.Error())
+			return fmt.Errorf("unable to write gzip meric: %w", err)
 		}
 	}
 
 	err := gz.Close()
 	if err != nil {
-		return fmt.Errorf("unable to close gzip, %s", err.Error())
+		return fmt.Errorf("unable to close gzip: %w", err)
 	}
 
 	return l.send(buff.Bytes())
@@ -112,14 +112,14 @@ func (l *Logzio) Write(metrics []telegraf.Metric) error {
 func (l *Logzio) send(metrics []byte) error {
 	req, err := http.NewRequest("POST", l.authURL(), bytes.NewBuffer(metrics))
 	if err != nil {
-		return fmt.Errorf("unable to create http.Request, %s", err.Error())
+		return fmt.Errorf("unable to create http.Request: %w", err)
 	}
 	req.Header.Add("Content-Type", "application/json")
 	req.Header.Set("Content-Encoding", "gzip")
 
 	resp, err := l.client.Do(req)
 	if err != nil {
-		return fmt.Errorf("error POSTing metrics, %s", err.Error())
+		return fmt.Errorf("error POSTing metrics: %w", err)
 	}
 	defer resp.Body.Close()
 
