@@ -16,8 +16,6 @@ import (
 	"github.com/influxdata/telegraf/plugins/serializers"
 )
 
-// DO NOT REMOVE THE NEXT TWO LINES! This is required to embed the sampleConfig data.
-//
 //go:embed sample.conf
 var sampleConfig string
 
@@ -123,7 +121,7 @@ func (m *MQTT) Write(metrics []telegraf.Metric) error {
 
 			err = m.client.Publish(topic, buf)
 			if err != nil {
-				return fmt.Errorf("could not write to MQTT server, %s", err)
+				return fmt.Errorf("could not write to MQTT server: %w", err)
 			}
 		}
 	}
@@ -136,7 +134,7 @@ func (m *MQTT) Write(metrics []telegraf.Metric) error {
 		}
 		err = m.client.Publish(key, buf)
 		if err != nil {
-			return fmt.Errorf("could not write to MQTT server, %s", err)
+			return fmt.Errorf("could not write to MQTT server: %w", err)
 		}
 	}
 
