@@ -4,6 +4,7 @@ package syslog
 import (
 	"crypto/tls"
 	_ "embed"
+	"errors"
 	"fmt"
 	"net"
 	"strconv"
@@ -120,10 +121,11 @@ func (s *Syslog) Write(metrics []telegraf.Metric) (err error) {
 			continue
 		}
 		if _, err = s.Conn.Write(msgBytesWithFraming); err != nil {
-			if netErr, ok := err.(net.Error); ok {
+			var netErr net.Error
+			if errors.As(err, &netErr) {
 				s.Close() //nolint:revive // There is another error which will be returned here
 				s.Conn = nil
-				return fmt.Errorf("closing connection: %v", netErr)
+				return fmt.Errorf("closing connection: %w", netErr)
 			}
 			return err
 		}
