@@ -11,6 +11,7 @@ import (
 	"strconv"
 	"strings"
 	"time"
+	"unicode/utf8"
 
 	_ "time/tzdata" // needed to bundle timezone info into the binary for Windows
 
@@ -23,6 +24,9 @@ import (
 
 type TimeFunc func() time.Time
 
+const replacementByte = "\ufffd"
+const commaByte = "\u002C"
+
 type Parser struct {
 	ColumnNames        []string        `toml:"csv_column_names"`
 	ColumnTypes        []string        `toml:"csv_column_types"`
@@ -34,6 +38,7 @@ type Parser struct {
 	SkipColumns        int             `toml:"csv_skip_columns"`
 	SkipRows           int             `toml:"csv_skip_rows"`
 	TagColumns         []string        `toml:"csv_tag_columns"`
+	TagOverwrite       bool            `toml:"csv_tag_overwrite"`
 	TimestampColumn    string          `toml:"csv_timestamp_column"`
 	TimestampFormat    string          `toml:"csv_timestamp_format"`
 	Timezone           string          `toml:"csv_timezone"`
@@ -50,6 +55,8 @@ type Parser struct {
 
 	gotColumnNames bool
 
+	invalidDelimiter bool
+
 	TimeFunc     func() time.Time
 	DefaultTags  map[string]string
 	metadataTags map[string]string
@@ -140,6 +147,7 @@ func (p *Parser) Init() error {
 		if len(runeStr) > 1 {
 			return fmt.Errorf("csv_delimiter must be a single character, got: %s", p.Delimiter)
 		}
+		p.invalidDelimiter = !validDelim(runeStr[0])
 	}
 
 	if p.Comment != "" {
@@ -155,7 +163,7 @@ func (p *Parser) Init() error {
 	}
 
 	if err := p.initializeMetadataSeparators(); err != nil {
-		return fmt.Errorf("initializing separators failed: %v", err)
+		return fmt.Errorf("initializing separators failed: %w", err)
 	}
 
 	if p.TimeFunc == nil {
@@ -181,9 +189,13 @@ func (p *Parser) compile(r io.Reader) *csv.Reader {
 	csvReader := csv.NewReader(r)
 	// ensures that the reader reads records of different lengths without an error
 	csvReader.FieldsPerRecord = -1
-	if p.Delimiter != "" {
+	if !p.invalidDelimiter && p.Delimiter != "" {
 		csvReader.Comma = []rune(p.Delimiter)[0]
 	}
+	// Check if delimiter is invalid
+	if p.invalidDelimiter && p.Delimiter != "" {
+		csvReader.Comma = []rune(commaByte)[0]
+	}
 	if p.Comment != "" {
 		csvReader.Comment = []rune(p.Comment)[0]
 	}
@@ -191,12 +203,23 @@ func (p *Parser) compile(r io.Reader) *csv.Reader {
 	return csvReader
 }
 
+// Taken from upstream Golang code see
+// https://github.com/golang/go/blob/release-branch.go1.19/src/encoding/csv/reader.go#L95
+func validDelim(r rune) bool {
+	return r != 0 && r != '"' && r != '\r' && r != '\n' && utf8.ValidRune(r) && r != utf8.RuneError
+}
+
 func (p *Parser) Parse(buf []byte) ([]telegraf.Metric, error) {
 	// Reset the parser according to the specified mode
 	if p.ResetMode == "always" {
 		p.Reset()
 	}
-
+	// If using an invalid delimiter, replace commas with replacement and
+	// invalid delimiter with commas
+	if p.invalidDelimiter {
+		buf = bytes.Replace(buf, []byte(commaByte), []byte(replacementByte), -1)
+		buf = bytes.Replace(buf, []byte(p.Delimiter), []byte(commaByte), -1)
+	}
 	r := bytes.NewReader(buf)
 	metrics, err := parseCSV(p, r)
 	if err != nil && errors.Is(err, io.EOF) {
@@ -314,6 +337,18 @@ func (p *Parser) parseRecord(record []string) (telegraf.Metric, error) {
 	recordFields := make(map[string]interface{})
 	tags := make(map[string]string)
 
+	if p.TagOverwrite {
+		// add default tags
+		for k, v := range p.DefaultTags {
+			tags[k] = v
+		}
+
+		// add metadata tags
+		for k, v := range p.metadataTags {
+			tags[k] = v
+		}
+	}
+
 	// skip columns in record
 	record = record[p.SkipColumns:]
 outer:
@@ -358,17 +393,17 @@ outer:
 				case "int":
 					val, err = strconv.ParseInt(value, 10, 64)
 					if err != nil {
-						return nil, fmt.Errorf("column type: parse int error %s", err)
+						return nil, fmt.Errorf("column type: parse int error %w", err)
 					}
 				case "float":
 					val, err = strconv.ParseFloat(value, 64)
 					if err != nil {
-						return nil, fmt.Errorf("column type: parse float error %s", err)
+						return nil, fmt.Errorf("column type: parse float error %w", err)
 					}
 				case "bool":
 					val, err = strconv.ParseBool(value)
 					if err != nil {
-						return nil, fmt.Errorf("column type: parse bool error %s", err)
+						return nil, fmt.Errorf("column type: parse bool error %w", err)
 					}
 				default:
 					val = value
@@ -391,14 +426,16 @@ outer:
 		}
 	}
 
-	// add metadata tags
-	for k, v := range p.metadataTags {
-		tags[k] = v
-	}
+	if !p.TagOverwrite {
+		// add metadata tags
+		for k, v := range p.metadataTags {
+			tags[k] = v
+		}
 
-	// add default tags
-	for k, v := range p.DefaultTags {
-		tags[k] = v
+		// add default tags
+		for k, v := range p.DefaultTags {
+			tags[k] = v
+		}
 	}
 
 	// will default to plugin name
@@ -471,6 +508,7 @@ func (p *Parser) InitFromConfig(config *parsers.Config) error {
 	p.ColumnNames = config.CSVColumnNames
 	p.ColumnTypes = config.CSVColumnTypes
 	p.TagColumns = config.CSVTagColumns
+	p.TagOverwrite = config.CSVTagOverwrite
 	p.MeasurementColumn = config.CSVMeasurementColumn
 	p.TimestampColumn = config.CSVTimestampColumn
 	p.TimestampFormat = config.CSVTimestampFormat
