@@ -10,6 +10,7 @@ import (
 	"github.com/stretchr/testify/require"
 
 	"github.com/influxdata/telegraf"
+	"github.com/influxdata/telegraf/internal/choice"
 	"github.com/influxdata/telegraf/plugins/parsers"
 	_ "github.com/influxdata/telegraf/plugins/parsers/all"
 )
@@ -20,6 +21,7 @@ func TestRegistry_BackwardCompatibility(t *testing.T) {
 		CSVHeaderRowCount: 42,
 		XPathProtobufFile: "xpath/testcases/protos/addressbook.proto",
 		XPathProtobufType: "addressbook.AddressBook",
+		JSONStrict:        true,
 	}
 
 	// Some parsers need certain settings to not error. Furthermore, we
@@ -42,7 +44,14 @@ func TestRegistry_BackwardCompatibility(t *testing.T) {
 		},
 	}
 
+	// Define parsers that do not have an old-school init
+	newStyleOnly := []string{"binary"}
+
 	for name, creator := range parsers.Parsers {
+		if choice.Contains(name, newStyleOnly) {
+			t.Logf("skipping new-style-only %q...", name)
+			continue
+		}
 		t.Logf("testing %q...", name)
 		cfg.DataFormat = name
 
@@ -77,7 +86,7 @@ func TestRegistry_BackwardCompatibility(t *testing.T) {
 			options = append(options, cmpopts.IgnoreFields(stype, settings.mask...))
 		}
 
-		// Do a manual comparision as require.EqualValues will also work on unexported fields
+		// Do a manual comparison as require.EqualValues will also work on unexported fields
 		// that cannot be cleared or ignored.
 		diff := cmp.Diff(expected, actual, options...)
 		require.Emptyf(t, diff, "Difference for %q", name)
